Enclosure - Betty 0.4.0a3 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Enclosure

An `betty.model.ancestry.Enclosure` acts as a bridge that links places together that enclose, or contain each other.

## Fields

`citations` (iterable of Citation)

  The citations for this enclosure.

`date` (Datey)

  When these places enclosed each other.

`encloses` (Place)

  The place that is enclosed by the `enclosed_by`.

`enclosed_by` (Place)

  The place that encloses `encloses`.

`id` (`str`)

  The enclosure’s own entity ID.